@@ -16,41 +16,14 @@ from typing import Callable,List, Any, Generator, Tuple
 import requests.exceptions
 
 log=logging.getLogger(__name__)
-
-def enter_and_leave_function(func: Callable) -> Callable:
-    @functools.wraps(func)
-    def wrapper(*args: Any, **kwargs: Any) -> Any:
-        func_def_file = inspect.getsourcefile(func) or "unknown_file"
-        func_def_file = func_def_file.split("/")[-1]
-        func_def_line = inspect.getsourcelines(func)[1] if func_def_file != "unknown_file" else "unknown_line"
-        log.info(
-            f"[{func_def_file}: {func_def_line}]"
-            f"[{func.__name__}()]"
-            f"| args={args}, kwargs={kwargs}"
-        )
-
-        try:
-            result = func(*args, **kwargs)
-            log.info(
-                f"[{func_def_file}: {func_def_line}]"
-                f" finish run function {func.__name__}(), return value is: {result} "
-            )
-            return result
-
-        except Exception as e:
-            error_traceback = traceback.format_exc()
-
-            log.error(
-                f"[{func_def_file}: {func_def_line}]"
-                f"failed to run function {func.__name__}() :Failed. "
-                f"| error_type：{type(e).__name__} "
-                f"| error_message：{str(e)} "
-                f"| full_stack_trace：\n{error_traceback}",
-                exc_info=False
-            )
-            raise
-
-    return wrapper
+log.setLevel(logging.WARNING)
+formatter = logging.Formatter(
+    fmt="%(asctime)s | %(levelname)s | %(name)s | %(filename)s:%(lineno)d | %(message)s",
+    datefmt="%Y-%m-%d %H:%M:%S"
+)
+console_handler = logging.StreamHandler()
+console_handler.setFormatter(formatter)
+log.addHandler(console_handler)
 
 class Gitee():
     def __init__(self):
@@ -141,7 +114,7 @@ class RepoRpmParser:
             file_pattern = re.compile(r'href="([a-f0-9]+-primary\.xml(\.[a-z0-9]+)?)"')
             files = file_pattern.findall(resp.text)
             file_list = list({f[0] for f in files})
-            log.debug(f"Found repodata files: {file_list}")
+            log.info(f"Found repodata files: {file_list}")
             return file_list
         except Exception as e:
             log.error(f"Failed to get repodata file list from {repodata_url}: {str(e)}")
@@ -155,7 +128,7 @@ class RepoRpmParser:
                 for chunk in resp.iter_content(chunk_size=8192):
                     if chunk:
                         f.write(chunk)
-            log.debug(f"Downloaded file: {file_url} -> {save_path}")
+            log.info(f"Downloaded file: {file_url} -> {save_path}")
             return True
         except Exception as e:
             log.error(f"Failed to download {file_url}: {str(e)}")
@@ -179,7 +152,7 @@ class RepoRpmParser:
             else:
                 log.error(f"Unsupported compression format: {compressed_path}")
                 return False
-            log.debug(f"Decompressed file: {compressed_path} -> {output_path}")
+            log.info(f"Decompressed file: {compressed_path} -> {output_path}")
             return True
         except Exception as e:
             log.error(f"Failed to decompress {compressed_path}: {str(e)}")
@@ -196,7 +169,7 @@ class RepoRpmParser:
                 packages = root.findall(".//default:package[@type='rpm']",
                                         namespaces={"default": self.ns_map["default"]})
 
-            log.debug(f"Found {len(packages)} RPM packages in primary.xml")
+            log.info(f"Found {len(packages)} RPM packages in primary.xml")
             for pkg in packages:
                 name_elem = pkg.find("name")
                 if name_elem is None:
@@ -205,7 +178,7 @@ class RepoRpmParser:
                     pkg_name = name_elem.text.strip()
                     if pkg_name:
                         rpm_names.add(pkg_name)
-                        log.debug(f"Extracted package name: {pkg_name}")
+                        log.info(f"Extracted package name: {pkg_name}")
             result = sorted(list(rpm_names))
             log.info(f"Extracted {len(result)} unique RPM package names")
             return result
